@@ -10,9 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
 import uuid
 
+from tempest.lib.common.utils import data_utils
 from tempest.lib import exceptions
 
 from openstackclient.tests.functional import base
@@ -29,16 +29,22 @@ class QuotaTests(base.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        super(QuotaTests, cls).setUpClass()
+        super().setUpClass()
         cls.haz_network = cls.is_service_enabled('network')
-        cls.PROJECT_NAME =\
-            cls.get_openstack_configuration_value('auth.project_name')
+        cls.PROJECT_NAME = data_utils.rand_name('TestProject')
+        cls.openstack(f'project create {cls.PROJECT_NAME}')
+
+    @classmethod
+    def tearDownClass(cls):
+        cls.openstack(f'project delete {cls.PROJECT_NAME}')
+        super().tearDownClass()
 
     def test_quota_list_details_compute(self):
         expected_headers = ["Resource", "In Use", "Reserved", "Limit"]
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --detail --compute'
-        ))
+        cmd_output = self.openstack(
+            'quota list --detail --compute',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         resources = []
         for row in cmd_output:
@@ -52,9 +58,10 @@ class QuotaTests(base.TestCase):
 
     def test_quota_list_details_network(self):
         expected_headers = ["Resource", "In Use", "Reserved", "Limit"]
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --detail --network'
-        ))
+        cmd_output = self.openstack(
+            'quota list --detail --network',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         resources = []
         for row in cmd_output:
@@ -70,9 +77,10 @@ class QuotaTests(base.TestCase):
         if not self.haz_network:
             self.skipTest("No Network service present")
         self.openstack('quota set --networks 40 ' + self.PROJECT_NAME)
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --network'
-        ))
+        cmd_output = self.openstack(
+            'quota list --network',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         self.assertEqual(
             40,
@@ -81,9 +89,10 @@ class QuotaTests(base.TestCase):
 
     def test_quota_list_compute_option(self):
         self.openstack('quota set --instances 30 ' + self.PROJECT_NAME)
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --compute'
-        ))
+        cmd_output = self.openstack(
+            'quota list --compute',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         self.assertEqual(
             30,
@@ -92,9 +101,10 @@ class QuotaTests(base.TestCase):
 
     def test_quota_list_volume_option(self):
         self.openstack('quota set --volumes 20 ' + self.PROJECT_NAME)
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --volume'
-        ))
+        cmd_output = self.openstack(
+            'quota list --volume',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         self.assertEqual(
             20,
@@ -107,13 +117,15 @@ class QuotaTests(base.TestCase):
         if self.haz_network:
             network_option = "--routers 21 "
         self.openstack(
-            'quota set --cores 31 --backups 41 ' +
-            network_option +
-            self.PROJECT_NAME
+            'quota set --cores 31 --backups 41 '
+            + network_option
+            + self.PROJECT_NAME
         )
-        cmd_output = json.loads(self.openstack(
-            'quota show -f json ' + self.PROJECT_NAME
-        ))
+        cmd_output = self.openstack(
+            'quota show ' + self.PROJECT_NAME,
+            parse_output=True,
+        )
+        cmd_output = {x['Resource']: x['Limit'] for x in cmd_output}
         self.assertIsNotNone(cmd_output)
         self.assertEqual(
             31,
@@ -130,12 +142,14 @@ class QuotaTests(base.TestCase):
             )
 
         # Check default quotas
-        cmd_output = json.loads(self.openstack(
-            'quota show -f json --default'
-        ))
+        cmd_output = self.openstack(
+            'quota show --default',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         # We don't necessarily know the default quotas, we're checking the
         # returned attributes
+        cmd_output = {x['Resource']: x['Limit'] for x in cmd_output}
         self.assertTrue(cmd_output["cores"] >= 0)
         self.assertTrue(cmd_output["backups"] >= 0)
         if self.haz_network:
@@ -143,13 +157,14 @@ class QuotaTests(base.TestCase):
 
     def test_quota_set_class(self):
         self.openstack(
-            'quota set --key-pairs 33 --snapshots 43 ' +
-            '--class default'
+            'quota set --key-pairs 33 --snapshots 43 ' + '--class default'
+        )
+        cmd_output = self.openstack(
+            'quota show --class default',
+            parse_output=True,
         )
-        cmd_output = json.loads(self.openstack(
-            'quota show -f json --class default'
-        ))
         self.assertIsNotNone(cmd_output)
+        cmd_output = {x['Resource']: x['Limit'] for x in cmd_output}
         self.assertEqual(
             33,
             cmd_output["key-pairs"],
@@ -160,45 +175,57 @@ class QuotaTests(base.TestCase):
         )
 
         # Check default quota class
-        cmd_output = json.loads(self.openstack(
-            'quota show -f json --class'
-        ))
+        cmd_output = self.openstack(
+            'quota show --class',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         # We don't necessarily know the default quotas, we're checking the
         # returned attributes
+        cmd_output = {x['Resource']: x['Limit'] for x in cmd_output}
         self.assertTrue(cmd_output["key-pairs"] >= 0)
         self.assertTrue(cmd_output["snapshots"] >= 0)
 
     def _restore_quota_limit(self, resource, limit, project):
         self.openstack('quota set --%s %s %s' % (resource, limit, project))
 
-    def test_quota_network_set_with_check_limit(self):
+    def test_quota_network_set_with_no_force(self):
         if not self.haz_network:
             self.skipTest('No Network service present')
         if not self.is_extension_enabled('quota-check-limit'):
             self.skipTest('No "quota-check-limit" extension present')
 
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --network'
-        ))
-        self.addCleanup(self._restore_quota_limit, 'network',
-                        cmd_output[0]['Networks'], self.PROJECT_NAME)
+        cmd_output = self.openstack(
+            'quota list --network',
+            parse_output=True,
+        )
+        self.addCleanup(
+            self._restore_quota_limit,
+            'network',
+            cmd_output[0]['Networks'],
+            self.PROJECT_NAME,
+        )
 
         self.openstack('quota set --networks 40 ' + self.PROJECT_NAME)
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --network'
-        ))
+        cmd_output = self.openstack(
+            'quota list --network',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         self.assertEqual(40, cmd_output[0]['Networks'])
 
         # That will ensure we have at least two networks in the system.
         for _ in range(2):
-            self.openstack('network create --project %s %s' %
-                           (self.PROJECT_NAME, uuid.uuid4().hex))
+            self.openstack(
+                'network create --project %s %s'
+                % (self.PROJECT_NAME, uuid.uuid4().hex)
+            )
 
-        self.assertRaises(exceptions.CommandFailed, self.openstack,
-                          'quota set --networks 1 --check-limit ' +
-                          self.PROJECT_NAME)
+        self.assertRaises(
+            exceptions.CommandFailed,
+            self.openstack,
+            'quota set --networks 1 --no-force ' + self.PROJECT_NAME,
+        )
 
     def test_quota_network_set_with_force(self):
         self.skipTest('story 2010110')
@@ -214,27 +241,36 @@ class QuotaTests(base.TestCase):
         if not self.is_extension_enabled('quota-check-limit'):
             self.skipTest('No "quota-check-limit" extension present')
 
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --network'
-        ))
-        self.addCleanup(self._restore_quota_limit, 'network',
-                        cmd_output[0]['Networks'], self.PROJECT_NAME)
+        cmd_output = self.openstack(
+            'quota list --network',
+            parse_output=True,
+        )
+        self.addCleanup(
+            self._restore_quota_limit,
+            'network',
+            cmd_output[0]['Networks'],
+            self.PROJECT_NAME,
+        )
 
         self.openstack('quota set --networks 40 ' + self.PROJECT_NAME)
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --network'
-        ))
+        cmd_output = self.openstack(
+            'quota list --network',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         self.assertEqual(40, cmd_output[0]['Networks'])
 
         # That will ensure we have at least two networks in the system.
         for _ in range(2):
-            self.openstack('network create --project %s %s' %
-                           (self.PROJECT_NAME, uuid.uuid4().hex))
+            self.openstack(
+                'network create --project %s %s'
+                % (self.PROJECT_NAME, uuid.uuid4().hex)
+            )
 
         self.openstack('quota set --networks 1 --force ' + self.PROJECT_NAME)
-        cmd_output = json.loads(self.openstack(
-            'quota list -f json --network'
-        ))
+        cmd_output = self.openstack(
+            'quota list --network',
+            parse_output=True,
+        )
         self.assertIsNotNone(cmd_output)
         self.assertEqual(1, cmd_output[0]['Networks'])
